@import url(https://fonts.googleapis.com/css?family=Roboto:500);

html, body {
    font-family: 'Titillium Web', sans-serif;
}


h1.header {
    color: #c9a87e;
    text-align: center;
    font-weight: bold;
}

h2 {
    font-weight: 400;
}

.spec {
    font-weight: bold;
}

.description {
    font-weight: 200;
    font-style: italic;
    color: #303030;
}

.api-class {
    margin: 35px 30px 35px 30px;
    padding: 10px 16px 10px 16px;
    color: #303030;
    background-color: #ffffff;
    box-shadow: 0 4px 8px 0 rgba(227, 227, 227, 0.75);
    border: 1px solid #2c3e50;
    border-radius: 4px;
    /*background-color: #0d5aa7;*/
}

.specification {
    background-color: #f4f1ed;
    padding: 10px;
    margin: 0
}

.method {
    background-color: #f4f1ed;
    padding: 10px;
    margin: 0
}

.api-sub-class {
    margin: 30px 0 30px 0;
    cursor: pointer;
    /*background-color: #2d2d2d;*/
}

.post-tag {
    background-color: #b36440;
    border-radius: 6px 6px 0 0;
}

.get-tag {
    background-color: #40b379;
    border-radius: 6px 6px 0 0;
}

.insert-tag {
    background-color: #5a87b3;
    border-radius: 6px 6px 0 0;
}

.put-tag {
    background-color: #9b67b3;
    border-radius: 6px 6px 0 0;
}

.other-tag {
    background-color: #939393;
    border-radius: 6px 6px 0 0;
}

.drop-down-menu {
    display: none;
}

.route {
    font-family: Courier, sans-serif;
    padding: 15px;
    background-color: #2c3e50;
    margin: 0;
    color: #b2b244;
}

.code-box {
    padding: 15px;
    font-family: Courier, sans-serif;
    font-size: 1em;
    line-height: 1.3;
    color: #fff;
    background-color: #2c3e50;
    -webkit-border-radius: 0 0 6px 6px;
    -moz-border-radius: 0 0 6px 6px;
    border-radius: 0 0 6px 6px;
    margin-bottom: 10px;
    margin-top: 0;
}